.. CytoFlow documentation master file, created by
   sphinx-quickstart on Fri Mar  6 19:42:50 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to CytoFlow's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2
   
   design
   TODO

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

